@@ -13,6 +13,7 @@ Simple interface, simple deploy.
 
 # TODO tidy up these imports
 
+from dns import resolver as dns
 from hstspreload import in_hsts_preload
 import pendulum  # TODO XXX
 from requests.exceptions import ConnectionError
@@ -38,7 +39,9 @@ from .response import (Status,  # noqa
                        MethodNotAllowed, Conflict, Gone)
 # from .tasks import run_queue
 
-__all__ = ["in_hsts_preload", "mf", "mkdn", "mm", "template", "templates",
-           "pendulum", "indieauth", "micropub", "microsub", "webmention",
-           "websub", "run_queue", "uri", "Created", "ConnectionError"]
+
+__all__ = ["dns", "in_hsts_preload", "mf", "mkdn", "mm", "template",
+           "templates", "pendulum", "indieauth", "micropub", "microsub",
+           "webmention", "websub", "run_queue", "uri", "Created",
+           "ConnectionError"]
 __all__ += agent.__all__ + braid.__all__ + framework.__all__  # noqa
