@@ -20,11 +20,12 @@ from selenium.webdriver.support.ui import WebDriverWait
 
 from understory import mf
 from understory import solarized
+from understory import sql
 from understory import uri
 from understory import web
 
 __all__ = ["post", "get", "put", "delete",
-           "parse", "browser", "cache", "discover_link", "download"]
+           "parse", "browser", "firefox", "cache", "discover_link", "download"]
 
 displays = []
 browsers = []
@@ -143,8 +144,10 @@ class Cache:
             self.domain = domain
         if db:
             self.db = db
-            self.db.define(cache="""url TEXT UNIQUE, html TEXT,
-                                    headers JSON, data JSON""")
+        else:
+            self.db = sql.db("cache.db")
+        self.db.define(cache="""url TEXT UNIQUE, html TEXT,
+                                headers JSON, data JSON""")
 
     def format_url(self, url):
         try:
@@ -238,8 +241,8 @@ class Transaction:
 
     @property
     def card(self):
-        return Semantics(mf.representative_hcard(self.mf2json.data,
-                                                 source_url=self.url))
+        return Semantics(mf.representative_card(self.mf2json.data,
+                                                source_url=self.url))
 
     @property
     def feed(self):
