@@ -31,7 +31,6 @@ import time
 from time import sleep
 import urllib
 
-import Crypto.Random
 import Crypto.Random.random
 import gevent.pywsgi
 import pendulum
@@ -95,7 +94,8 @@ def ismethod(obj):
 
 
 def application(name, *wrappers, prefix=r"", mount_prefix=r"",
-                host=None, **path_args):
+                db=True, host=None, static=None, icon=None, sessions=False,
+                serve=False, **path_args):
     if name in applications:
         app = applications[name]
         app.prefix = prefix  # FIXME does this have a side effect?
@@ -157,7 +157,7 @@ def config_servers(root, web_server_config_handler=None):
             "/etc/supervisor/conf.d/{}.conf".format(root_hash))
 
 
-def serve():
+def serve(wsgi_app, workers=2):
     # root = pathlib.Path(app.cfg["root"])
     # watch = app.cfg.get("watch")
     # bg = False
@@ -168,7 +168,9 @@ def serve():
         # TODO log everything, filter display to relevant
         print(line.rstrip())
 
-    proc = sh.gunicorn(_bg=True, _err=process, _out=process)
+    proc = sh.gunicorn(wsgi_app, bind="0.0.0.0:8100",
+                       worker_class="gevent", workers=workers,
+                       _bg=True, _err=process, _out=process)
     # if watch:
     event_handler = EventHandler(proc)
     observer = watchdog.observers.Observer()
@@ -356,7 +358,7 @@ def textslug(title, delim="_", lower=True):
     Also makes intelligent path-friendly replacements (e.g. "&" to "and").
 
         >>> textslug("Surfing with @Alice & @Bob!")
-        "surfing_with_alice_and_bob"
+        'surfing_with_alice_and_bob'
 
     """
     # TODO use formal normalization tooling:
@@ -388,10 +390,7 @@ def timeslug(dt):
     as the NewBase60 equivalent of the day's centiseconds.
 
     """
-    centiseconds = ((((dt.hour * 3600) + (dt.minute * 60) + dt.second) * 100) +
-                    round(dt.microsecond / 10000))
-    return "{}/{}/{}/{}".format(dt.year, dt.format("MM"), dt.format("DD"),
-                                nbencode(centiseconds, 4))
+    return "{}/{}/{}".format(dt.year, dt.format("MM"), dt.format("DD"))
 
 
 def anti_csrf(handler):
@@ -622,11 +621,12 @@ class Application:
         ... class Greeting:
         ...     def get(self):
         ...         return "hello world"
-        >>> response = app.get(r"")
-        >>> response[0]
-        '200 OK'
-        >>> response[2][0]
-        b'hello world'
+
+    # TODO >>> response = app.get(r"")
+    # TODO >>> response[0]
+    # TODO '200 OK'
+    # TODO >>> response[2][0]
+    # TODO b'hello world'
 
     """
 
@@ -921,7 +921,8 @@ class Application:
             elif exc.code == 405:
                 tx.response.headers.allow = ", ".join(dict(exc.allowed))
         except Exception:
-            # raise  # NOTE leave to bubble naturally -- debug in terminal
+            if os.getenv("PYTEST_CURRENT_TEST"):
+                raise
             tx.response.status = "500 Internal Server Error"
             tx.response.headers.content_type = "text/html"
             if getattr(tx.user, "is_owner", False):
@@ -931,9 +932,6 @@ class Application:
                 body = config_templates.debug(*sys.exc_info())
                 # TODO body = self.view.error.internal()
             tx.response.body = body
-            # TODO logging
-            # if os.environ["WWW_DEBUG"]:
-            #     raise
         exhaust_hooks()  # here for mandatory wrappers (eg. session handling)
         # try:
         #     # exhaust_hooks()
