@@ -11,7 +11,8 @@ from gevent import local
 import lxml
 import lxml.html
 
-from ... import uri
+from understory import uri
+
 from ..headers import Headers
 
 __all__ = ["tx", "header", "shift_headings", "json", "JSONEncoder"]
