@@ -1,6 +1,7 @@
 """Mountable IndieWeb apps and helper functions."""
 
-from ... import mm
+from understory import mm
+
 from .. import framework as fw
 from . import indieauth
 from . import micropub
