@@ -1,6 +1,7 @@
 """Micropub server app."""
 
 import pathlib
+import random
 
 import pendulum
 import sh
@@ -17,7 +18,7 @@ from .util import discover_post_type
 server = web.application("MicropubServer", mount_prefix="pub", db=False,
                          channel=r".+", entry=r".+", nickname=r"[A-Za-z0-9-]+",
                          filename=rf"{web.nb60_re}{{4}}.\w{{1,10}}")
-content = web.application("Content", mount_prefix=r"\d{{4}}", db=False,
+content = web.application("MicropubContent", db=False,
                           year=r"\d{4}", month=r"\d{2}", day=r"\d{2}",
                           seconds=web.nb60_re + r"{,4}", slug=r"[\w_-]+")
 templates = web.templates(__name__)
@@ -37,8 +38,8 @@ def send(properties, endpoint=None, h="entry", token=None):
 
 def define_table():
     """Define the `resources`, `media` and `syndication` tables."""
-    tx.db.define(resources="""resource JSON, version TEXT UNIQUE,
-                              parents JSON""",
+    tx.db.define(resources="""permalink TEXT UNIQUE, version TEXT UNIQUE,
+                              resource JSON""",
                  # TODO updates="""""",
                  media="""mid TEXT, sha256 TEXT UNIQUE, size INTEGER""",
                  syndication="""destination JSON NOT NULL""")
@@ -209,10 +210,6 @@ class LocalClient:
             #     textslug = follows[0]["name"]
             #     mentions.append(follows[0]["url"])
             #     tx.sub.follow(follows[0]["url"])
-            path = f"/{web.timeslug(published[0]['datetime'])}"
-            if slug:
-                path += f"/{web.textslug(slug)}"
-            urls.append(path)
             author_id = tx.db.select("resources",
                                      where="""json_extract(resources.resource,
                                                   '$.uid[0]') == ?""",
@@ -225,17 +222,34 @@ class LocalClient:
         #     #     pass
         resource.update(published=published, url=urls)
         resource["type"] = [resource_type]
-        resource_kwargs = dict(resource=resource, version=web.nbrandom(10))
         # XXX from pprint import pprint
         # XXX pprint(resource_kwargs)
-        tx.db.insert("resources", **resource_kwargs)
+        permalink_base = f"/{web.timeslug(published[0]['datetime'])}"
+
+        def generate_trailer():
+            letterspace = "abcdefghijkmnopqrstuvwxyz23456789"
+            trailer = "".join([random.choice(letterspace) for i in range(2)])
+            if trailer in ("bs",):
+                return generate_trailer()
+            else:
+                return trailer
+
+        while True:
+            permalink = f"{permalink_base}/{generate_trailer()}"
+            resource["url"].append(permalink)
+            try:
+                tx.db.insert("resources", permalink=permalink,
+                             version=web.nbrandom(10), resource=resource)
+            except tx.db.IntegrityError:
+                continue
+            break
         web.publish("/recent", ".feed[-0:-0]", resource)
         for mention in mentions:
-            web.enqueue(webmention.send, f"{tx.origin}{path}", mention)
+            web.enqueue(webmention.send, f"{tx.origin}{permalink}", mention)
         # TODO web.publish(mention, ".responses[-1:-1]", resource)
         # for subscriber in subscribers:
         #     web.enqueue(websub.publish)
-        return urls[0]
+        return permalink
 
     def read(self, url):
         """Return an entry with its metadata."""
@@ -942,7 +956,7 @@ class MediaFile:
         return "deleted"
 
 
-@content.route(r"{month}/{day}/{seconds}(/{slug})?")
+@content.route(r"{year}/{month}/{day}/{seconds}(/{slug})?")
 class Permalink:
     """An individual entry."""
 
