@@ -2,10 +2,7 @@
 
 """
 
-try:
-    import regex as re
-except ImportError:
-    import re  # noqa
+import regex as re
 
 
 class Status(Exception):
